# Python Package Exercise

An exercise to create a Python package, build it, test it, distribute it, and use it. See [instructions](./instructions.md) for details.

token- pypi-AgEIcHlwaS5vcmcCJDkwMDhmOGQ3LTQ5MzMtNDlmYy04MzZiLTIzNTFhNTBmNDY2YwACKlszLCIyMjQ1M2MxNC1lZjgzLTRkZWYtODllOC00N2I0N2NmNzE1MmYiXQAABiBurCneLFH7NYG42iK_nleHWJwzDI8Km_7ftxGWQ8fphA

[pypi]
  username = __token__
  password = pypi-AgEIcHlwaS5vcmcCJDkwMDhmOGQ3LTQ5MzMtNDlmYy04MzZiLTIzNTFhNTBmNDY2YwACKlszLCIyMjQ1M2MxNC1lZjgzLTRkZWYtODllOC00N2I0N2NmNzE1MmYiXQAABiBurCneLFH7NYG42iK_nleHWJwzDI8Km_7ftxGWQ8fphA